@@ -703,12 +703,15 @@ gb_bookmark_set_add_to_context_menu (GbBookmark *b, gboolean val)
 {
 	g_return_if_fail (GB_IS_BOOKMARK (b));
 
-	b->add_to_context_menu = val;
-
-	g_signal_emit (b, GbBookmarkSignals[GB_BOOKMARK_MODIFIED], 0);
-	gb_folder_emit_child_modified (b->parent, b);
-
-	gb_bookmark_set_needs_saving (b);
+	if (b->add_to_context_menu != val)
+	{
+		b->add_to_context_menu = val;
+		
+		g_signal_emit (b, GbBookmarkSignals[GB_BOOKMARK_MODIFIED], 0);
+		gb_folder_emit_child_modified (b->parent, b);
+		
+		gb_bookmark_set_needs_saving (b);
+	}
 }
 
 void
@@ -2395,46 +2398,9 @@ gb_alias_placeholder_set_create_toolbar (GbAliasPlaceholder *ap, gboolean val)
 /**
  * BookmarkSet object
  */
-GType 
-gb_bookmark_set_get_type (void)
-{
-        static GType gb_bookmark_set_type = 0;
-
-        if (gb_bookmark_set_type == 0)
-        {
-                static const GTypeInfo our_info =
-                {
-                        sizeof (GbBookmarkSetClass),
-                        NULL, /* base_init */
-                        NULL, /* base_finalize */
-                        (GClassInitFunc) gb_bookmark_set_class_init,
-                        NULL,
-                        NULL, /* class_data */
-                        sizeof (GbBookmarkSet),
-                        0, /* n_preallocs */
-                        (GInstanceInitFunc) gb_bookmark_set_init
-                };
-		
-		static const GInterfaceInfo autocompletion_source_info =
-			{
-				(GInterfaceInitFunc) gb_bookmark_set_autocompletion_source_init,
-				NULL,
-				NULL
-			};
-
-                gb_bookmark_set_type = g_type_register_static (G_TYPE_OBJECT,
-							      "GbBookmarkSet",
-							      &our_info, 0);
-
-		g_type_add_interface_static (gb_bookmark_set_type,
-					     GALEON_TYPE_AUTOCOMPLETION_SOURCE,
-					     &autocompletion_source_info);
-
-        }
-
-        return gb_bookmark_set_type;
-
-}
+MAKE_GET_TYPE_IFACE (gb_bookmark_set, "GbBookmarkSet", GbBookmarkSet,
+		     gb_bookmark_set_class_init, gb_bookmark_set_init, G_TYPE_OBJECT,
+		     gb_bookmark_set_autocompletion_source_init, GALEON_TYPE_AUTOCOMPLETION_SOURCE);
 
 static void
 gb_bookmark_set_class_init (GbBookmarkSetClass *klass)
@@ -2754,7 +2720,7 @@ gb_bookmark_set_add_default (GbBookmarkSet *set, GbBookmark *b)
 static char *
 gb_bookmark_set_fix_galeon1_mess_string (const gchar *s)
 {
-	char *sl = g_locale_from_utf8 (s, -1, NULL, NULL, NULL);
+	char *sl = g_convert (s, -1, "ISO-8859-1", "UTF-8", NULL, NULL, NULL);
 	if (sl) 
 	{
 		/* check if the result is valid */
@@ -2901,7 +2867,7 @@ gb_bookmark_set_get_url_by_nick_and_args (GbBookmarkSet *set,
 		return NULL;
 	}
 	
-	if (GB_IS_SMART_SITE (b))
+	if (GB_IS_SMART_SITE (b) && tokens[1])
 	{
 		ret = gb_smart_site_subst_args (GB_SMART_SITE (b), tokens + 1);
 	}
