@@ -23,7 +23,9 @@
 #include "eel-gconf-extensions.h"
 #include "galeon-config.h"
 #include "gul-bonobo-extensions.h"
+#include "gul-download.h"
 #include "galeon-embed-helper-list.h"
+#include "galeon-marshal.h"
 
 #include <string.h>
 #include <bonobo/bonobo-ui-component.h>
@@ -34,7 +36,8 @@ typedef enum
 {
 	EMBED_POPUP_INPUT,
 	EMBED_POPUP_DOCUMENT,
-	EMBED_POPUP_ELEMENT
+	EMBED_POPUP_ELEMENT,
+	EMBED_POPUP_SELECTION
 } EmbedPopupType;
 
 struct GaleonEmbedPopupPrivate
@@ -44,7 +47,6 @@ struct GaleonEmbedPopupPrivate
 	GaleonEmbed *embed;
 	EmbedEventContext context;
 	BonoboUIComponent *ui_component;
-	char *selection;
 	EmbedPopupType popup_type;
 };
 
@@ -108,9 +110,20 @@ embed_popup_copy_to_clipboard (GaleonEmbedPopup *popup, const char *text);
 
 static GObjectClass *parent_class = NULL;
 
+/**
+ * Signals enums and ids
+ */
+enum GaleonEmbedPopupSignalsEnum {
+	GALEON_EMBED_POPUP_BEFORE_SHOW,
+	GALEON_EMBED_POPUP_LAST_SIGNAL
+};
+static gint GaleonEmbedPopupSignals[GALEON_EMBED_POPUP_LAST_SIGNAL];
+
+
 #define DOCUMENT_POPUP_PATH "/popups/GaleonEmbedDocumentPopup"
 #define ELEMENT_POPUP_PATH "/popups/GaleonEmbedElementPopup"
 #define INPUT_POPUP_PATH "/popups/GaleonEmbedInputPopup"
+#define SELECTION_POPUP_PATH "/popups/GaleonEmbedSelectionPopup"
 
 #define GALEON_POPUP_NAVIGATION_ITEMS_PLACEHOLDER "/popups/GaleonEmbedDocumentPopup/NavigationItems"
 #define GALEON_POPUP_LINK_ITEMS_PLACEHOLDER "/popups/GaleonEmbedElementPopup/LinkItems"
@@ -180,6 +193,15 @@ galeon_embed_popup_class_init (GaleonEmbedPopupClass *klass)
         object_class->finalize = galeon_embed_popup_finalize;
 
 	klass->show = NULL; /* abstract */
+
+	GaleonEmbedPopupSignals[GALEON_EMBED_POPUP_BEFORE_SHOW] = g_signal_new (
+		"before-show", G_OBJECT_CLASS_TYPE (klass),  
+		G_SIGNAL_RUN_FIRST | G_SIGNAL_RUN_LAST | G_SIGNAL_RUN_CLEANUP,
+                G_STRUCT_OFFSET (GaleonEmbedPopupClass, before_show), 
+		NULL, NULL, 
+		galeon_marshal_VOID__VOID,
+		G_TYPE_NONE, 0);
+
 }
 
 static void
@@ -209,8 +231,6 @@ galeon_embed_popup_finalize (GObject *object)
 		g_object_unref (G_OBJECT (gep->priv->event));
 	}	
 	
-	g_free (gep->priv->selection);
-	
         g_free (gep->priv);
 	
         G_OBJECT_CLASS (parent_class)->finalize (object);
@@ -221,7 +241,7 @@ setup_image_openwith (GaleonEmbedPopup *p)
 {
 	GaleonEmbedEvent *info;
 	const char *url;
-	GValue *value;
+	const GValue *value;
 	GaleonEmbedHelperList *hl;
 	
 	info = galeon_embed_popup_get_event (p);
@@ -304,7 +324,7 @@ static void
 setup_document_menu (GaleonEmbedPopup *p)
 {	
 	gboolean is_framed;
-	GValue *value;
+	const GValue *value;
 	gboolean has_background;
 	gboolean is_sidebar = p->priv->context & EMBED_CONTEXT_SIDEBAR;
 	
@@ -354,6 +374,12 @@ galeon_embed_popup_set_event (GaleonEmbedPopup *p,
 	{
 		p->priv->popup_type = EMBED_POPUP_INPUT;
 	}
+	else if (galeon_embed_event_has_property (event, "selection"))
+	{
+		/* TODO here we could set up some additional menu items that
+		 * use the selected text, like smart bookmarks for example */
+		p->priv->popup_type = EMBED_POPUP_SELECTION;
+	}
 	else
 	{
 		setup_document_menu (p);
@@ -429,7 +455,7 @@ embed_popup_copy_email_cmd (BonoboUIComponent *uic,
 {
 	GaleonEmbedEvent *info;
 	const char *location;
-	GValue *value;
+	const GValue *value;
 	
 	info = galeon_embed_popup_get_event (popup);
 	galeon_embed_event_get_property (info, "email", &value);
@@ -444,7 +470,7 @@ embed_popup_copy_link_location_cmd (BonoboUIComponent *uic,
 {
 	GaleonEmbedEvent *info;
 	const char *location;
-	GValue *value;
+	const GValue *value;
 	
 	info = galeon_embed_popup_get_event (popup);
 	galeon_embed_event_get_property (info, "link", &value);
@@ -460,7 +486,7 @@ save_property_url (GaleonEmbedPopup *popup,
 {
 	GaleonEmbedEvent *info;
 	const char *location;
-	GValue *value;
+	const GValue *value;
 	GtkWidget *widget;
 	GtkWidget *window;
 	GaleonEmbedPersist *persist;
@@ -482,8 +508,18 @@ save_property_url (GaleonEmbedPopup *popup,
 						EMBED_PERSIST_SHOW_PROGRESS);
 	}
 	
+	if (!ask_dest)
+	{
+		/* if we're not asking for download directory, make sure the
+		 * file is downloaded in the specified download directory and
+		 * not somewhere else */
+		char *dir = eel_gconf_get_string (CONF_DOWNLOADING_DIR);
+		eel_gconf_set_string (CONF_STATE_LAST_DOWNLOAD_DIR, dir);
+		g_free (dir);
+	}
+
 	galeon_embed_utils_save (window,
-				 CONF_DOWNLOADING_DIR,
+				 CONF_STATE_LAST_DOWNLOAD_DIR,
 				 ask_dest,
                                  FALSE,
                                  persist);
@@ -505,6 +541,9 @@ galeon_embed_popup_get_popup_path (GaleonEmbedPopup *p)
 		case EMBED_POPUP_DOCUMENT:
 			result = DOCUMENT_POPUP_PATH;
 			break;
+		case EMBED_POPUP_SELECTION:
+			result = SELECTION_POPUP_PATH;
+			break;
 	}
 	
 	return result;
@@ -517,15 +556,13 @@ embed_popup_download_link_cmd (BonoboUIComponent *uic,
                       	       GaleonEmbedPopup *popup, 
                                const char* verbname)
 {
-	/* FIXME External downloader helper is not compiled because
-	 * it uses galeon-shell. Utils should not do it
         if (eel_gconf_get_boolean(CONF_DOWNLOADING_EXTERNAL_DOWNLOADER) ==
             DOWNLOADER_EXTERNAL)
         {
 
 		GaleonEmbedEvent *info;
 		const char *location;
-		GValue *value;
+		const GValue *value;
 
 		info = galeon_embed_popup_get_event (popup);
 		galeon_embed_event_get_property (info, "link", &value);
@@ -533,7 +570,7 @@ embed_popup_download_link_cmd (BonoboUIComponent *uic,
 
 		return gul_download_external_save_url (location);
         }
-	else*/
+	else
 	{
 		save_property_url (popup,
 				   eel_gconf_get_boolean 
@@ -584,7 +621,7 @@ embed_popup_set_image_as_background_cmd (BonoboUIComponent *uic,
 	GaleonEmbedEvent *info;
 	const char *location;
 	char *dest, *base;
-	GValue *value;
+	const GValue *value;
 	GaleonEmbedPersist *persist;
 	
 	info = galeon_embed_popup_get_event (popup);
@@ -618,7 +655,7 @@ embed_popup_copy_image_location_cmd (BonoboUIComponent *uic,
 {
 	GaleonEmbedEvent *info;
 	const char *location;
-	GValue *value;
+	const GValue *value;
 	
 	info = galeon_embed_popup_get_event (popup);
 	galeon_embed_event_get_property (info, "image", &value);
@@ -704,7 +741,7 @@ embed_popup_open_image_cmd (BonoboUIComponent *uic,
 {
 	GaleonEmbedEvent *info;
 	const char *location;
-	GValue *value;
+	const GValue *value;
 	
 	info = galeon_embed_popup_get_event (popup);
 	galeon_embed_event_get_property (info, "image", &value);
