@@ -55,9 +55,7 @@ GProgressListener::GProgressListener () : mLauncher(nsnull),
 					  mPersist(nsnull),
 				          mHandler(nsnull),
 					  mObserver(nsnull),
-#if MOZILLA_SNAPSHOT > 1
 					  mMIMEInfo(nsnull),
-#endif
 					  mPercentComplete(0)
 {
 	NS_INIT_ISUPPORTS ();
@@ -189,11 +187,7 @@ NS_METHOD GProgressListener::PrivateInit (void)
 NS_IMETHODIMP GProgressListener::Init(nsIURI *aSource,
                                       nsILocalFile *aTarget,
                                       const PRUnichar *aDisplayName,
-#if MOZILLA_SNAPSHOT > 1
 				      nsIMIMEInfo *aMIMEInfo,
-#else
-				      const PRUnichar *aOpeningWith,
-#endif
                                       PRInt64 aStartTime,
                                       nsIWebBrowserPersist *aPersist)
 {
@@ -202,11 +196,9 @@ NS_IMETHODIMP GProgressListener::Init(nsIURI *aSource,
         mTimeDownloadStarted = aStartTime;
         mStartTime = aStartTime;
         mPersist = aPersist;
-#if MOZILLA_SNAPSHOT > 1
 	mMIMEInfo = aMIMEInfo;
-#endif
         mAction = ACTION_NONE;
-#if MOZILLA_SNAPSHOT > 1
+
 	if(mMIMEInfo)
 	{
 		nsMIMEInfoHandleAction mimeAction;
@@ -216,7 +208,7 @@ NS_IMETHODIMP GProgressListener::Init(nsIURI *aSource,
 				  ACTION_SAVEFORHELPER : ACTION_NONE;
 		}
 	}
-#endif
+
         mNoDialog = 0;
 
         return PrivateInit();
@@ -247,24 +239,16 @@ NS_IMETHODIMP GProgressListener::GetSource(nsIURI * *aSource)
 /* attribute nsILocalFile target; */
 NS_IMETHODIMP GProgressListener::GetTarget(nsILocalFile * *aTarget)
 {
-        nsCOMPtr<nsILocalFile> aLocalFile = do_QueryInterface(mFile);
-        NS_IF_ADDREF(*aTarget = aLocalFile);
+        nsCOMPtr<nsILocalFile> localFile = do_QueryInterface(mFile);
+        NS_IF_ADDREF(*aTarget = localFile);
         return NS_OK;
 }
 
-#if MOZILLA_SNAPSHOT > 1
 NS_IMETHODIMP GProgressListener::GetMIMEInfo(nsIMIMEInfo * *aMIMEInfo)
 {
 	NS_IF_ADDREF(*aMIMEInfo = mMIMEInfo);
 	return NS_OK;
 }
-#else
-NS_IMETHODIMP GProgressListener::GetOpeningWith(PRUnichar * *aOpeningWith)
-{
-	*aOpeningWith = NULL;
-	return NS_OK;
-}
-#endif
 
 /* attribute nsIObserver observer; */
 NS_IMETHODIMP GProgressListener::GetObserver(nsIObserver * *aObserver)
@@ -323,7 +307,6 @@ NS_IMETHODIMP GProgressListener::GetDialog(nsIDOMWindow * *aDialog)
         return NS_OK;
 }
 
-#if MOZILLA_SNAPSHOT > 1
 /* attribute PRBool cancelDownloadOnClose; */
 NS_IMETHODIMP  GProgressListener::GetCancelDownloadOnClose(PRBool *aCancelDownloadOnClose)
 {
@@ -333,8 +316,6 @@ NS_IMETHODIMP  GProgressListener::SetCancelDownloadOnClose(PRBool aCancelDownloa
 {
     return NS_ERROR_NOT_IMPLEMENTED;
 }
-#endif
-
 
 NS_IMETHODIMP GProgressListener::LaunchHandler (PersistHandlerInfo *handler)
 {
@@ -352,9 +333,9 @@ NS_IMETHODIMP GProgressListener::LaunchHandler (PersistHandlerInfo *handler)
 	nsAutoString uFileName;
         
 	mFile->GetPath(uFileName);
-        const nsACString &aFileName = NS_ConvertUCS2toUTF8(uFileName);
+        const nsACString &cFileName = NS_ConvertUCS2toUTF8(uFileName);
 	
-	char *fname = g_strdup(PromiseFlatCString(aFileName).get());
+	char *fname = g_strdup(PromiseFlatCString(cFileName).get());
 	gul_general_launch_application (handler->command,
 					fname,
 					handler->need_terminal);
@@ -381,18 +362,7 @@ NS_IMETHODIMP GProgressListener::OnStateChange (nsIWebProgress *aWebProgress,
 		switch (mAction)
                 {
 		case ACTION_SAVEFORHELPER:
-#if MOZILLA_SNAPSHOT > 1
 			LaunchHelperApp();
-#else
-			if (mLauncher)
-                        {
-                                mLauncher->CloseProgressWindow ();
-                        }
-                        if (mHandler)
-                        {
-                                mHandler->LaunchHelperApp ();
-                        }
-#endif
 			break;
 			
 		case ACTION_NONE:
@@ -402,18 +372,20 @@ NS_IMETHODIMP GProgressListener::OnStateChange (nsIWebProgress *aWebProgress,
 			}
 			break;
 		case ACTION_OBJECT_NOTIFY:
-			PersistHandlerInfo *handler;
-			
-			g_object_get (mGaleonPersist,
-		      		      "handler", &handler,        
-		      		      NULL);
 
-			if (handler)
+			if (G_IS_OBJECT(mGaleonPersist))
 			{
-				LaunchHandler (handler);
+				PersistHandlerInfo *handler(nsnull);
+				g_object_get (mGaleonPersist,
+			      		      "handler", &handler,        
+			      		      NULL);
+				if (handler)
+				{
+					LaunchHandler (handler);
+				}
+
+				g_signal_emit_by_name (mGaleonPersist, "completed");
 			}
-			
-			g_signal_emit_by_name (mGaleonPersist, "completed");
 		}
 		
 		if (!mNoDialog)
@@ -455,7 +427,7 @@ NS_IMETHODIMP GProgressListener::
 		mCheckedCanPause = PR_TRUE;
 
 		nsresult rv;
-		nsCOMPtr<nsIFTPChannel> aChannel = 
+		nsCOMPtr<nsIFTPChannel> channel = 
 			do_QueryInterface (aRequest, &rv);
 
 		mCanPause = (NS_SUCCEEDED (rv) ? PR_TRUE : PR_FALSE);
@@ -611,8 +583,8 @@ NS_METHOD GProgressListener::LaunchHelperApp (void)
 		}
 	}
 
-	nsCAutoString aFileName;
-	mFile->GetNativePath(aFileName);
+	nsCAutoString cFileName;
+	mFile->GetNativePath(cFileName);
 	if(NS_FAILED(rv)) return NS_ERROR_FAILURE;
 
 	nsXPIDLString helperDesc;
@@ -624,7 +596,7 @@ NS_METHOD GProgressListener::LaunchHelperApp (void)
 		TRUE : FALSE;
 
 	gul_general_launch_application (helperFileName.get(),
-					aFileName.get(),
+					cFileName.get(),
 					terminalHelper);
 
 	return NS_OK;
