@@ -27,12 +27,14 @@
 #include "mozilla-notifiers.h"
 #include "mozilla-i18n.h"
 #include "eel-gconf-extensions.h"
+#include "galeon-embed-prefs.h"
 #include "MozRegisterComponents.h"
 #include "FilePicker.h"
 #include "SideBar.h"
 #include "nsIConsoleService.h"
 #include "JSConsoleListener.h"
 #include "nsIJSConsoleService.h"
+#include "mozilla-cookie.h"
 
 #include <time.h>
 #include <libgnome/gnome-i18n.h>
@@ -214,6 +216,85 @@ mozilla_embed_shell_class_init (MozillaEmbedShellClass *klass)
 	shell_class->show_file_picker = impl_show_file_picker;
 }
 
+static void
+mozilla_load_proxy_prefs (MozillaEmbedShell *shell)
+{
+	char *tmp;
+	int i, mozilla_mode = 0;
+	
+	/* Proxy mode */
+	tmp = eel_gconf_get_string(CONF_NETWORK_PROXY_MODE);
+	
+	if (!tmp)
+	{
+		mozilla_mode = 0;
+	}
+	else if (strcmp(tmp, "manual") == 0)
+	{
+		mozilla_mode = 1;
+	}
+	else if (strcmp(tmp, "auto") == 0)
+	{
+		mozilla_mode = 2;
+	}
+
+	mozilla_prefs_set_int("network.proxy.type", mozilla_mode);
+	g_free(tmp);
+
+	/* Http proxy */
+	tmp = eel_gconf_get_string(CONF_NETWORK_HTTP_PROXY);
+	if (tmp)
+	{
+		mozilla_prefs_set_string("network.proxy.http", tmp);
+		g_free (tmp);
+	}
+
+	i = eel_gconf_get_integer(CONF_NETWORK_HTTP_PROXY_PORT);
+	mozilla_prefs_set_int("network.proxy.http_port", i);
+	
+	/* Ftp proxy */
+	tmp = eel_gconf_get_string(CONF_NETWORK_FTP_PROXY);
+	if (tmp)
+	{
+		mozilla_prefs_set_string("network.proxy.ftp", tmp);
+		g_free(tmp);
+	}
+
+	i = eel_gconf_get_integer(CONF_NETWORK_FTP_PROXY_PORT);
+	mozilla_prefs_set_int("network.proxy.ftp_port", i);
+
+	/* Secure proxy */
+	tmp = eel_gconf_get_string(CONF_NETWORK_SSL_PROXY);
+	if (tmp)
+	{
+		mozilla_prefs_set_string("network.proxy.ssl", tmp);
+		g_free(tmp);
+	}
+
+	i = eel_gconf_get_integer(CONF_NETWORK_SSL_PROXY_PORT);
+	mozilla_prefs_set_int("network.proxy.ssl_port", i);
+
+	/* Socks proxy */
+	tmp = eel_gconf_get_string(CONF_NETWORK_SOCKS_PROXY);
+	if (tmp)
+	{
+		mozilla_prefs_set_string("network.proxy.socks", tmp);
+		g_free(tmp);
+	}
+
+	i = eel_gconf_get_integer(CONF_NETWORK_SOCKS_PROXY_PORT);
+	mozilla_prefs_set_int("network.proxy.socks_port", i);
+
+	/* Autoconfiguration */
+	tmp = eel_gconf_get_string(CONF_NETWORK_PROXY_AUTO_URL);
+	if (tmp)
+	{
+		galeon_embed_shell_load_proxy_autoconf 
+			(GALEON_EMBED_SHELL (shell), tmp);
+		g_free (tmp);
+	}
+}
+
 static void
 mozilla_set_default_prefs (void)
 {
@@ -245,7 +326,7 @@ mozilla_set_default_prefs (void)
         /* set the right accept encoding flags */
         mozilla_prefs_set_string ("network.http.accept-encoding" ,
                                   "gzip, deflate, compress;q=0.9");
-
+	
         mozilla_prefs_save ();
 }
 
@@ -315,13 +396,6 @@ is_new_build (void)
 	return new_build;
 }
 
-static void
-mozilla_init_prefs (void)
-{
-	mozilla_set_default_prefs ();
-	mozilla_notifiers_set_defaults ();
-}
-
 static void
 mozilla_init_js_console (MozillaEmbedShell *mes)
 {
@@ -337,11 +411,43 @@ mozilla_init_js_console (MozillaEmbedShell *mes)
 	mozilla_js_console = G_OBJECT(mes->priv->js_console);
 }
 
+static gboolean
+have_gnome_url_handler (const gchar *protocol)
+{
+	gchar *key, *cmd;
+	gboolean rv;
+
+	key = g_strdup_printf ("/desktop/gnome/url-handlers/%s/command", 
+			       protocol);
+	cmd = eel_gconf_get_string (key);
+	g_free (key);
+
+	rv = (cmd != NULL);
+	g_free (cmd);
+
+	if (!rv) return rv;
+
+	key = g_strdup_printf ("/desktop/gnome/url-handlers/%s/enabled", 
+			       protocol);
+	rv = eel_gconf_get_boolean (key);
+	g_free (key);
+
+	return rv;
+}
+
 static void
 mozilla_register_external_protocols (void)
 {
 	/* FIXME register only when needed */
-	mozilla_register_FtpProtocolHandler ();
+	if (have_gnome_url_handler ("ftp"))
+	{
+		mozilla_register_FtpProtocolHandler ();
+	}
+	else
+	{
+		mozilla_unregister_FtpProtocolHandler ();
+	}
+
 	mozilla_register_MailtoProtocolHandler ();
 	mozilla_register_gHelpProtocolHandlers ();
 }
@@ -359,7 +465,6 @@ mozilla_embed_shell_init (MozillaEmbedShell *mes)
 	new_build = is_new_build ();
 	
 	/* Pre initialization */
-	mozilla_notifiers_init (mes);
 	mozilla_init_home ();
 	mozilla_init_profile ();
 	
@@ -367,11 +472,15 @@ mozilla_embed_shell_init (MozillaEmbedShell *mes)
 	gtk_moz_embed_push_startup ();
 
 	/* Post initialization */
+	mozilla_notifiers_init (mes);
+
 	if (new_build)
 	{
-		mozilla_init_prefs ();
+		mozilla_set_default_prefs ();
 	}
 
+	mozilla_load_proxy_prefs (mes);
+	
 	mozilla_init_single (mes);
 	
 	mozilla_register_components ();
@@ -713,21 +822,12 @@ impl_get_font_list (GaleonEmbedShell *shell,
 	    enumResult == PR_TRUE;
 	    fontEnum->HasMoreElements(&enumResult))
 	{
-#if MOZILLA_SNAPSHOT > 2
 		nsCOMPtr<nsISupportsString> fontName;
-#else
-		nsCOMPtr<nsISupportsWString> fontName;
-#endif
 		fontEnum->GetNext(getter_AddRefs(fontName));
 		if(NS_FAILED(rv)) return G_FAILED;
 
-#if MOZILLA_SNAPSHOT > 2
 		nsString fontString;
 		fontName->GetData(fontString);
-#else
-		nsXPIDLString fontString;
-		fontName->GetData(getter_Copies(fontString));
-#endif
 
 		char *gFontString;
 		gFontString = g_strdup(NS_ConvertUCS2toUTF8(fontString).get());
@@ -757,12 +857,8 @@ impl_set_permission (GaleonEmbedShell *shell,
 	nsCOMPtr<nsIPermissionManager> permissionManager =
                         do_CreateInstance (NS_PERMISSIONMANAGER_CONTRACTID);
 
-#if MOZILLA_SNAPSHOT > 2
         rv = permissionManager->Add (nsDependentCString(url),
         			     allow ? PR_TRUE : PR_FALSE, type);
-#else
-        rv = permissionManager->Add (url, allow ? PR_TRUE : PR_FALSE, type);
-#endif
 	if (NS_FAILED(rv)) return G_FAILED;
 
 	return G_OK;
@@ -805,10 +901,7 @@ impl_list_permissions (GaleonEmbedShell *shell,
 
                         PRBool cap;
                         nsPermission->GetCapability (&cap);
-                        if (cap == PR_TRUE) 
-                                b->type = g_strdup (_("Allowed"));
-                        else 
-                                b->type = g_strdup (_("Blocked"));
+			b->status = cap;
 
                         *permissions = g_list_prepend (*permissions, b);
                 }
@@ -828,16 +921,11 @@ impl_remove_permissions (GaleonEmbedShell *shell,
         nsCOMPtr<nsIPermissionManager> permissionManager =
                         do_CreateInstance (NS_PERMISSIONMANAGER_CONTRACTID);
 
-        for (GList *permissions = g_list_first(permissions); permissions != NULL;
-             permissions = g_list_next(permissions))
+        for (GList *l = permissions; l != NULL; l = l->next)
         {
-                PermissionInfo *b = (PermissionInfo *)permissions->data;
-#if MOZILLA_SNAPSHOT > 2
+                PermissionInfo *b = (PermissionInfo *)l->data;
                 result = permissionManager->Remove (nsDependentCString(b->domain),
                 				    type);
-#else
-                result = permissionManager->Remove (b->domain, type);
-#endif
                 if (NS_FAILED(result)) return G_FAILED;
         };
 
@@ -862,39 +950,11 @@ impl_list_cookies (GaleonEmbedShell *shell,
              enumResult == PR_TRUE ;
              cookieEnumerator->HasMoreElements(&enumResult))
         {
-                CookieInfo *c;
-        
                 nsCOMPtr<nsICookie> nsCookie;
                 result = cookieEnumerator->GetNext (getter_AddRefs(nsCookie));
                 if (NS_FAILED(result)) return G_FAILED;
 
-                c = g_new0 (CookieInfo, 1);
-
-                nsCAutoString transfer;
-
-                nsCookie->GetHost (transfer);
-                c->base.domain = g_strdup (transfer.get());
-                nsCookie->GetName (transfer);
-                c->name = g_strdup (transfer.get());
-                nsCookie->GetValue (transfer);
-                c->value = g_strdup (transfer.get());
-                nsCookie->GetPath (transfer);
-                c->path = g_strdup (transfer.get());
-
-		PRBool isSecure;
-                nsCookie->GetIsSecure (&isSecure);
-                if (isSecure == PR_TRUE) 
-                        c->secure = g_strdup (_("Yes"));
-                else 
-                        c->secure = g_strdup (_("No"));
-
-                PRUint64 dateTime;
-                nsCookie->GetExpires (&dateTime);
-		if(dateTime == 0)
-			c->expire = g_strdup (_("End of current session"));
-		else
-	                c->expire = g_strdup_printf ("%s",ctime((time_t*)&dateTime));
-                
+                CookieInfo *c = mozilla_cookie_to_info (nsCookie);
                 *cookies = g_list_prepend (*cookies, c);
         }       
 
@@ -908,16 +968,14 @@ impl_remove_cookies (GaleonEmbedShell *shell,
 		     GList *cookies)
 {
 	nsresult result;
-	GList *cl;
         nsCOMPtr<nsICookieManager> cookieManager =
                         do_CreateInstance (NS_COOKIEMANAGER_CONTRACTID);
 	
-        for (cl = g_list_first(cookies) ; cl != NULL ; 
-             cl = g_list_next (cl))
+        for (GList *l = cookies; l != NULL; l = l->next)
         {
-                CookieInfo *c = (CookieInfo *)cl->data;
+                CookieInfo *c = (CookieInfo *)l->data;
 
-                result = cookieManager->Remove (NS_LITERAL_CSTRING(c->base.domain),
+                result = cookieManager->Remove (NS_LITERAL_CSTRING(c->domain),
                                                 NS_LITERAL_CSTRING(c->name),
                                                 NS_LITERAL_CSTRING(c->path),
                                                 PR_FALSE);
@@ -985,8 +1043,7 @@ impl_remove_passwords (GaleonEmbedShell *shell,
         nsCOMPtr<nsIPasswordManager> passwordManager =
                         do_CreateInstance (NS_PASSWORDMANAGER_CONTRACTID);
 
-        for (GList *l = g_list_first(passwords) ; l !=NULL ; 
-             l = g_list_next(l))
+        for (GList *l = passwords; l != NULL; l = l->next)
         {
                 PasswordInfo *p = (PasswordInfo *)l->data;
                 if (type == PASSWORD_PASSWORD)
@@ -1026,8 +1083,8 @@ impl_show_file_picker (GaleonEmbedShell *shell,
         else
                 showContentCheck = PR_TRUE;
 
-        GFilePicker *aFilePicker = new GFilePicker (showContentCheck, 
-                                                    file_formats);
+        GFilePicker *filePicker = new GFilePicker (showContentCheck, 
+                                                   file_formats);
 
         /* expand the tilde, if there is one */
         expanded_directory = gul_string_expand_home_dir (directory);
@@ -1041,17 +1098,17 @@ impl_show_file_picker (GaleonEmbedShell *shell,
                 expanded_directory = g_strdup (g_get_home_dir());
         }
 
-        nsCOMPtr<nsILocalFile> aDir = 
+        nsCOMPtr<nsILocalFile> dir = 
                                 do_CreateInstance (NS_LOCAL_FILE_CONTRACTID);
-        aDir->InitWithPath (NS_ConvertUTF8toUCS2(expanded_directory));
+        dir->InitWithNativePath (nsDependentCString(expanded_directory));
         g_free (expanded_directory);
 
-        aFilePicker->InitWithGtkWidget (parentWidget, title, mode);
-        aFilePicker->SetDefaultString (NS_ConvertUTF8toUCS2(file).get());
-        aFilePicker->SetDisplayDirectory (aDir);
+        filePicker->InitWithGtkWidget (parentWidget, title, mode);
+        filePicker->SetDefaultString (NS_ConvertUTF8toUCS2(file).get());
+        filePicker->SetDisplayDirectory (dir);
         
         PRInt16 retval;
-        aFilePicker->Show (&retval);
+        filePicker->Show (&retval);
 
         if (ret_save_content != NULL)
         {
@@ -1062,24 +1119,24 @@ impl_show_file_picker (GaleonEmbedShell *shell,
         }
         if (ret_file_format != NULL)
         {
-                *ret_file_format = aFilePicker->mSelectedFileFormat;
+                *ret_file_format = filePicker->mSelectedFileFormat;
         }
 
         if (retval == nsIFilePicker::returnCancel)
         {
-                delete aFilePicker;
+                delete filePicker;
                 return G_FAILED;
         }
         else
         {
                 if (*ret_fullpath)
                         g_free (*ret_fullpath);
-                nsCOMPtr<nsILocalFile> aFile;
-                aFilePicker->GetFile (getter_AddRefs(aFile));
-		nsAutoString tempFullPathStr;
-                aFile->GetPath (tempFullPathStr);
-                *ret_fullpath = g_strdup (NS_ConvertUCS2toUTF8(tempFullPathStr).get());
-                delete aFilePicker;
+                nsCOMPtr<nsILocalFile> file;
+                filePicker->GetFile (getter_AddRefs(file));
+		nsCAutoString tempFullPathStr;
+                file->GetNativePath (tempFullPathStr);
+                *ret_fullpath = g_strdup (tempFullPathStr.get());
+                delete filePicker;
                 return G_OK;
         }
 }
