@@ -352,7 +352,7 @@ gnv_embed_dom_mouse_down_cb (GaleonEmbed *embed,
 	else if (button == 1
 		 && (context & EMBED_CONTEXT_LINK))
 	{
-		GValue *value;
+		const GValue *value;
 		const gchar *url;
 		galeon_embed_event_get_property (event, "link", &value);
 		url = g_value_get_string (value);
@@ -549,7 +549,7 @@ gnv_popup_cmd_new_window (BonoboUIComponent *uic,
 {
 	GaleonEmbedEvent *info;
 	GaleonNautilusView *view;
-	GValue *value;
+	const GValue *value;
 
 	view = gnv_view_from_popup (popup);
 	
@@ -568,7 +568,7 @@ gnv_popup_cmd_image_in_new_window (BonoboUIComponent *uic,
 {
 	GaleonEmbedEvent *info;
 	GaleonNautilusView *view;
-	GValue *value;
+	const GValue *value;
 
 	view = gnv_view_from_popup (popup);
 	
