@@ -18,6 +18,7 @@
 
 #include "galeon-shell.h"
 #include "galeon-embed-shell.h"
+#include "galeon-embed-prefs.h"
 #include "eel-gconf-extensions.h"
 #include "prefs-strings.h"
 #include "bookmarks.h"
@@ -262,6 +263,66 @@ galeon_shell_get_embed_shell (GaleonShell *gs)
 	return gs->priv->embed_shell;
 }
 
+
+/* Old keys to be able to migrate old proxy prefs to the new location */
+#define OLD_NETWORK_PROXY_MODE "/apps/galeon/Advanced/Network/proxy_mode"
+#define OLD_NETWORK_HTTP_PROXY "/apps/galeon/Advanced/Network/http_proxy"
+#define OLD_NETWORK_SSL_PROXY "/apps/galeon/Advanced/Network/ssl_proxy"
+#define OLD_NETWORK_FTP_PROXY "/apps/galeon/Advanced/Network/ftp_proxy"
+#define OLD_NETWORK_SOCKS_PROXY "/apps/galeon/Advanced/Network/socks_proxy"
+#define OLD_NETWORK_HTTP_PROXY_PORT "/apps/galeon/Advanced/Network/http_proxy_port"
+#define OLD_NETWORK_SSL_PROXY_PORT "/apps/galeon/Advanced/Network/ssl_proxy_port"
+#define OLD_NETWORK_FTP_PROXY_PORT "/apps/galeon/Advanced/Network/ftp_proxy_port"
+#define OLD_NETWORK_SOCKS_PROXY_PORT "/apps/galeon/Advanced/Network/socks_proxy_port"
+#define OLD_NETWORK_PROXY_AUTO_URL "/apps/galeon/Advanced/Network/proxy_auto_url"
+#define CONF_NETWORK_PROXY_MIGRATED "/apps/galeon/Advanced/Network/proxy_prefs_converted"
+
+static void
+migrate_proxy_prefs ()
+{
+	const gchar *keys[][2] = 
+	{{OLD_NETWORK_HTTP_PROXY,       CONF_NETWORK_HTTP_PROXY},
+	 {OLD_NETWORK_SSL_PROXY,        CONF_NETWORK_SSL_PROXY},
+	 {OLD_NETWORK_FTP_PROXY,        CONF_NETWORK_FTP_PROXY},
+	 {OLD_NETWORK_SOCKS_PROXY,      CONF_NETWORK_SOCKS_PROXY}, 
+	 {OLD_NETWORK_HTTP_PROXY_PORT,  CONF_NETWORK_HTTP_PROXY_PORT},
+	 {OLD_NETWORK_SSL_PROXY_PORT,   CONF_NETWORK_SSL_PROXY_PORT},
+	 {OLD_NETWORK_FTP_PROXY_PORT,   CONF_NETWORK_FTP_PROXY_PORT},
+	 {OLD_NETWORK_SOCKS_PROXY_PORT, CONF_NETWORK_SOCKS_PROXY_PORT},
+	 {OLD_NETWORK_PROXY_AUTO_URL,   CONF_NETWORK_PROXY_AUTO_URL},
+	 {NULL, NULL}};
+	int proxy_mode;
+	const char *proxy_modes[3] = {"none", "manual", "auto"};
+	/* 
+	 * If the proxy prefs were never migrated, and if the user
+	 * has no prefs set for the gnome-wide proxy settings, migrate
+	 * its prefs
+	 */
+	if (!eel_gconf_key_exists (CONF_NETWORK_PROXY_AUTO_URL) &&
+	    !eel_gconf_get_boolean (CONF_NETWORK_PROXY_MIGRATED)) 
+	{
+		GConfValue *value;	
+		int i;
+
+		for (i=0; keys[i][0] != NULL; i++)
+		{		  
+			value = eel_gconf_get_value (keys[i][0]);
+			eel_gconf_set_value (keys[i][1], value);
+			eel_gconf_value_free (value);
+		}
+
+		proxy_mode = eel_gconf_get_integer (OLD_NETWORK_PROXY_MODE);
+		if (proxy_mode < 0 || proxy_mode > 2) 
+		{
+			proxy_mode = 0;
+		}
+		eel_gconf_set_string (CONF_NETWORK_PROXY_MODE, 
+				      proxy_modes[proxy_mode]);
+	}
+	
+	eel_gconf_set_boolean (CONF_NETWORK_PROXY_MIGRATED, TRUE);	
+}
+
 static void
 galeon_init_services (GaleonShell *gs)
 {
@@ -269,6 +330,9 @@ galeon_init_services (GaleonShell *gs)
 	/* it also enables notifiers support */
 	eel_gconf_monitor_add ("/apps/galeon");
 	eel_gconf_monitor_add ("/apps/nautilus/preferences");
+	eel_gconf_monitor_add ("/system/proxy");
+
+	migrate_proxy_prefs();
 
 	bookmarks_init (gs);
 
@@ -351,7 +415,7 @@ GaleonWindow *
 galeon_shell_get_active_window (GaleonShell *gs)
 {
 	Session *session;
-	GList *windows;
+	const GList *windows;
 	
 	session = galeon_shell_get_session (gs);
 	windows = session_get_windows (session);
@@ -625,3 +689,19 @@ galeon_shell_get_autocompletion (GaleonShell *gs)
 	return p->autocompletion;
 }
 
+GaleonNewTabFlags
+galeon_shell_modifier_flags (GdkModifierType modifier)
+{
+	GaleonNewTabFlags flags;
+	gboolean jump_to = eel_gconf_get_boolean (CONF_TABS_TABBED_AUTOJUMP);
+	gboolean new_tab = eel_gconf_get_boolean (CONF_TABS_TABBED);
+
+	if (modifier & GDK_CONTROL_MASK) jump_to = !jump_to;
+	if (modifier & GDK_SHIFT_MASK)   new_tab = !new_tab;
+
+	flags = 0;
+	flags |= jump_to ? GALEON_NEW_TAB_JUMP : GALEON_NEW_TAB_DONT_JUMP_TO;
+	flags |= new_tab ? GALEON_NEW_TAB_IN_EXISTING_WINDOW : GALEON_NEW_TAB_IN_NEW_WINDOW;
+
+	return flags;
+}
