@@ -48,13 +48,14 @@ struct _GaleonLocationEntryPrivate {
 	gint autocompletion_timeout;
 	gint show_alternatives_timeout;
 	gboolean block_set_autocompletion_key;
+	gboolean hack_for_going_to_the_site_when_clicking_in_the_location_history;
 
 	gchar *autocompletion_key;
 	gchar *last_completion;
 };
 
-#define AUTOCOMPLETION_DELAY 10
-#define SHOW_ALTERNATIVES_DELAY 100
+#define AUTOCOMPLETION_DELAY 200
+#define SHOW_ALTERNATIVES_DELAY 500
 
 /**
  * Private functions, only availble from this file
@@ -611,17 +612,29 @@ galeon_location_entry_list_event_after_cb (GtkWidget *list,
 	if (event->type == GDK_BUTTON_PRESS
 	    && ((GdkEventButton *) event)->button == 1)
 	{
-		gchar *url = galeon_location_entry_get_location (e);
-		g_signal_emit 
-			(e, GaleonLocationEntrySignals[GALEON_LOCATION_ENTRY_URL_ACTIVATED], 0, url);
-		g_free (url);
+		GaleonLocationEntryPrivate *p = e->priv;
+		p->hack_for_going_to_the_site_when_clicking_in_the_location_history = TRUE;
 	}
 }
 
 static void
 galeon_location_entry_editable_changed_cb (GtkEditable *editable, GaleonLocationEntry *e)
 {
+	GaleonLocationEntryPrivate *p = e->priv;
 	galeon_location_entry_set_autocompletion_key (e);
+
+	if (p->hack_for_going_to_the_site_when_clicking_in_the_location_history)
+	{
+		gchar *url = galeon_location_entry_get_location (e);
+		if (url && url[0] != '\0')
+		{
+			p->hack_for_going_to_the_site_when_clicking_in_the_location_history = FALSE;
+			g_signal_emit 
+				(e, GaleonLocationEntrySignals[GALEON_LOCATION_ENTRY_URL_ACTIVATED], 0, url);
+			g_free (url);
+		}
+	}
+
 }
 
 static void
